import React, { useMemo, useRef, useState, useEffect } from 'react'
import { Link } from 'react-router-dom'
import {useGoogleAuth} from 'hooks'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faUser } from '@fortawesome/free-solid-svg-icons'
import { AccountPage } from 'pages'
import { Box, Heading, Flex, Spacer, Button, Image, Avatar, HStack, Input } from "@chakra-ui/react"
import AppLogo from '../img/logo.png'
import NisumLogo from '../img/nisum.jpeg'
import '../styles/stylesheets/header.css'
import {
    Menu,
    MenuButton,
    MenuList,
    MenuItem,
    MenuItemOption,
    MenuGroup,
    MenuOptionGroup,
    MenuIcon,
    MenuCommand,
    MenuDivider,
    useDisclosure
  } from "@chakra-ui/react"

import { ChevronDownIcon } from '@chakra-ui/icons'


const Nav = () => {
    const { isSignedIn, signOut, signIn, manager } = useGoogleAuth();
    const handleAuth = () => { isSignedIn ? signOut() : signIn();}
    const authLinkText = useMemo(() => isSignedIn ? "Logout" : <FontAwesomeIcon icon={faUser} className="user-icon"/>, [isSignedIn]);
    const authMenuText = useMemo(() => isSignedIn ? "Logout" : "Login", [isSignedIn]);
    const { isOpen, onOpen, onClose } = useDisclosure();
    const btnRef = useRef<HTMLButtonElement>(null);
    const userName = isSignedIn ? <p>{manager.firstName} {manager.lastName}</p> : null
    const userIcon = isSignedIn ? 
    <Avatar boxSize="40px" borderRadius="full"  src={manager.imageUrl} alt="profile"/> : <div>{authLinkText}</div>




    return (
        <Flex className="header" justifyContent="space-between">
            <Box paddingTop="7px" paddingLeft="3px">
                <Image 
                    mt="-4px"
                    src={NisumLogo} 
                    alt="Nisum - Celebrating 20+ years logo"
                    height="40px"
                />
            </Box>
            <Box className="center-nav" display="-ms-inline-flexbox">
                <HStack>
                    <Link to="/"><Image src={AppLogo} alt="Order Management Console PRO logo" className="logo-img"/></Link>
                    <h1>Order Management</h1>
                    {/* <Link to="/"><h1>Order Management</h1></Link> */}
                </HStack>
            </Box>
            <Box marginTop="2.9px">
                <Menu>
                    <MenuButton rightIcon={<ChevronDownIcon />} onClick={onOpen} paddingRight="10px">
                        <HStack>
                            <span>{userIcon}</span> 
                            <span>{userName}</span>
                        </HStack>
                    </MenuButton>
                    <MenuList>
                        <MenuItem color="black"><Link to="/orders">Orders</Link></MenuItem>
                        <MenuItem color="black"><Link to="/account">Account</Link></MenuItem>
                        <MenuItem color="black"><button onClick={handleAuth}>{authMenuText}</button></MenuItem>
                    </MenuList>
                </Menu>
            </Box>
        </Flex>
    )
}

export default Nav
