import { Manager } from 'Manager'
import { tokenStorage } from 'utils'
import Axios, { AxiosError } from 'axios'

// const URL = (process.env.REACT_APP_BACKEND_URL as string)
const URL = process.env.ORDER_MANAGEMENT_BACKEND_URI

const BASE_PATH = `${URL}/api/managers`

export const authenticate = async (token: string): Promise<Manager> => {
    try {
        const { data } = await Axios.post(
            `${BASE_PATH}/auth`, 
            {}, // Empty body
            { 
                headers: { 
                    Authorization: `Bearer ${token}`  
                } 
            }
        )
        return data;   
    } catch (error) {
        const { response } = error as AxiosError;
        // Get Status Code
        return response?.data;
    }
}

export const getAccount = async (): Promise<Manager> => {
    const token = tokenStorage.get();
    try {
        const { data } = await Axios.get(
            `${BASE_PATH}/account`, 
            { headers: { Authorization: `Bearer ${token}` } }
        )
        return data;
    } catch (error) {
        const { response } = error as AxiosError;
        return response?.data;
    }
}

export const updateAccount = async (): Promise<Manager>  => {
    const token = tokenStorage.get();
    try {
        const { data } = await Axios.patch(
            `${BASE_PATH}/account`, 
            {}, // Empty body
            { headers: { Authorization: `Bearer ${token}` } }
        )
        return data;
    } catch (error) {
        const { response } = error as AxiosError;
        return response?.data;
    }
}

export const deleteAccount = async () => {
    const token = tokenStorage.get();
    try {
        await Axios.delete(
            `${BASE_PATH}/account`, 
            { headers: { Authorization: `Bearer ${token}` } }
        )
    } catch (error) {
        const { response } = error as AxiosError;
        return response?.data;
    }
}

export default {
    authenticate,
    getAccount,
    updateAccount,
    deleteAccount
}